@@ -12,7 +12,7 @@
  * Read the entire license text here: http://www.gnu.org/licenses/lgpl.html
  */
 
-// $Id: calendar.js 3060 2006-12-17 06:06:52Z chtito $
+// $Id: calendar.js 14469 2009-01-05 17:46:35Z FabianLange $
 
 /** The Calendar object constructor. */
 Calendar = function (firstDayOfWeek, dateStr, onSelected, onClose) {
@@ -1390,13 +1390,10 @@ Calendar.prototype.showAtElement = function (el, opts) {
 		document.body.appendChild(cp);
 		var br = Calendar.getAbsolutePos(cp);
 		document.body.removeChild(cp);
-		if (Calendar.is_ie) {
-			br.y += document.body.scrollTop;
-			br.x += document.body.scrollLeft;
-		} else {
-			br.y += window.scrollY;
-			br.x += window.scrollX;
-		}
+		if (document.body.scrollLeft){br.x += document.body.scrollLeft;}
+		br.x += window.scrollX;
+		if (document.body.scrollTop){br.y += document.body.scrollTop;}
+		br.y += window.scrollY;
 		var tmp = box.x + box.width - br.x;
 		if (tmp > 0) box.x -= tmp;
 		tmp = box.y + box.height - br.y;
