@@ -15,7 +15,7 @@
  * @subpackage config
  * @author     Fabien Potencier <fabien.potencier@symfony-project.com>
  * @author     Sean Kerr <sean@code-box.org>
- * @version    SVN: $Id: sfAutoloadConfigHandler.class.php 13098 2008-11-18 08:09:35Z Kris.Wallsmith $
+ * @version    SVN: $Id: sfAutoloadConfigHandler.class.php 17047 2009-04-06 14:43:02Z fabien $
  */
 class sfAutoloadConfigHandler extends sfYamlConfigHandler
 {
@@ -106,7 +106,7 @@ class sfAutoloadConfigHandler extends sfYamlConfigHandler
             if (isset($entry['prefix']))
             {
               // FIXME: does not work for plugins installed with a symlink
-              preg_match('~^'.str_replace('\*', '(.+?)', preg_quote(str_replace('/', DIRECTORY_SEPARATOR, $path), '~')).'~', $file, $match);
+              preg_match('~^'.str_replace('\*', '(.+?)', preg_quote(str_replace('/', DIRECTORY_SEPARATOR, $path), '~')).'~', str_replace('/', DIRECTORY_SEPARATOR, $file), $match);
               if (isset($match[$entry['prefix']]))
               {
                 $prefix = $match[$entry['prefix']].'/';
